:py:mod:`aiida.cmdline`
=======================

.. py:module:: aiida.cmdline

.. autodoc2-docstring:: aiida.cmdline
   :allowtitles:

Package Contents
----------------

Classes
~~~~~~~

.. list-table::
   :class: autosummary longtable
   :align: left

   * - :py:obj:`AbsolutePathParamType <aiida.cmdline.params.types.path.AbsolutePathParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.path.AbsolutePathParamType
          :summary:
   * - :py:obj:`CalculationParamType <aiida.cmdline.params.types.calculation.CalculationParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.calculation.CalculationParamType
          :summary:
   * - :py:obj:`CodeParamType <aiida.cmdline.params.types.code.CodeParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.code.CodeParamType
          :summary:
   * - :py:obj:`ComputerParamType <aiida.cmdline.params.types.computer.ComputerParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ComputerParamType
          :summary:
   * - :py:obj:`ConfigOptionParamType <aiida.cmdline.params.types.config.ConfigOptionParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.config.ConfigOptionParamType
          :summary:
   * - :py:obj:`DataParamType <aiida.cmdline.params.types.data.DataParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.data.DataParamType
          :summary:
   * - :py:obj:`DynamicEntryPointCommandGroup <aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup>`
     - .. autodoc2-docstring:: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup
          :summary:
   * - :py:obj:`EmailType <aiida.cmdline.params.types.strings.EmailType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EmailType
          :summary:
   * - :py:obj:`EntryPointType <aiida.cmdline.params.types.strings.EntryPointType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EntryPointType
          :summary:
   * - :py:obj:`FileOrUrl <aiida.cmdline.params.types.path.FileOrUrl>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.path.FileOrUrl
          :summary:
   * - :py:obj:`GroupParamType <aiida.cmdline.params.types.group.GroupParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.group.GroupParamType
          :summary:
   * - :py:obj:`HostnameType <aiida.cmdline.params.types.strings.HostnameType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.strings.HostnameType
          :summary:
   * - :py:obj:`IdentifierParamType <aiida.cmdline.params.types.identifier.IdentifierParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.identifier.IdentifierParamType
          :summary:
   * - :py:obj:`LabelStringType <aiida.cmdline.params.types.strings.LabelStringType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.strings.LabelStringType
          :summary:
   * - :py:obj:`LazyChoice <aiida.cmdline.params.types.choice.LazyChoice>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice
          :summary:
   * - :py:obj:`MpirunCommandParamType <aiida.cmdline.params.types.computer.MpirunCommandParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.computer.MpirunCommandParamType
          :summary:
   * - :py:obj:`MultipleValueParamType <aiida.cmdline.params.types.multiple.MultipleValueParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.multiple.MultipleValueParamType
          :summary:
   * - :py:obj:`NodeParamType <aiida.cmdline.params.types.node.NodeParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.node.NodeParamType
          :summary:
   * - :py:obj:`NonEmptyStringParamType <aiida.cmdline.params.types.strings.NonEmptyStringParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.strings.NonEmptyStringParamType
          :summary:
   * - :py:obj:`PathOrUrl <aiida.cmdline.params.types.path.PathOrUrl>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.path.PathOrUrl
          :summary:
   * - :py:obj:`PluginParamType <aiida.cmdline.params.types.plugin.PluginParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType
          :summary:
   * - :py:obj:`ProcessParamType <aiida.cmdline.params.types.process.ProcessParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.process.ProcessParamType
          :summary:
   * - :py:obj:`ProfileParamType <aiida.cmdline.params.types.profile.ProfileParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.profile.ProfileParamType
          :summary:
   * - :py:obj:`ShebangParamType <aiida.cmdline.params.types.computer.ShebangParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ShebangParamType
          :summary:
   * - :py:obj:`UserParamType <aiida.cmdline.params.types.user.UserParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.user.UserParamType
          :summary:
   * - :py:obj:`VerdiCommandGroup <aiida.cmdline.groups.verdi.VerdiCommandGroup>`
     - .. autodoc2-docstring:: aiida.cmdline.groups.verdi.VerdiCommandGroup
          :summary:
   * - :py:obj:`WorkflowParamType <aiida.cmdline.params.types.workflow.WorkflowParamType>`
     - .. autodoc2-docstring:: aiida.cmdline.params.types.workflow.WorkflowParamType
          :summary:

Functions
~~~~~~~~~

.. list-table::
   :class: autosummary longtable
   :align: left

   * - :py:obj:`dbenv <aiida.cmdline.utils.decorators.dbenv>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.decorators.dbenv
          :summary:
   * - :py:obj:`echo_critical <aiida.cmdline.utils.echo.echo_critical>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_critical
          :summary:
   * - :py:obj:`echo_dictionary <aiida.cmdline.utils.echo.echo_dictionary>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_dictionary
          :summary:
   * - :py:obj:`echo_error <aiida.cmdline.utils.echo.echo_error>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_error
          :summary:
   * - :py:obj:`echo_info <aiida.cmdline.utils.echo.echo_info>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_info
          :summary:
   * - :py:obj:`echo_report <aiida.cmdline.utils.echo.echo_report>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_report
          :summary:
   * - :py:obj:`echo_success <aiida.cmdline.utils.echo.echo_success>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_success
          :summary:
   * - :py:obj:`echo_warning <aiida.cmdline.utils.echo.echo_warning>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_warning
          :summary:
   * - :py:obj:`format_call_graph <aiida.cmdline.utils.ascii_vis.format_call_graph>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.ascii_vis.format_call_graph
          :summary:
   * - :py:obj:`is_verbose <aiida.cmdline.utils.common.is_verbose>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.common.is_verbose
          :summary:
   * - :py:obj:`only_if_daemon_running <aiida.cmdline.utils.decorators.only_if_daemon_running>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.decorators.only_if_daemon_running
          :summary:
   * - :py:obj:`with_dbenv <aiida.cmdline.utils.decorators.with_dbenv>`
     - .. autodoc2-docstring:: aiida.cmdline.utils.decorators.with_dbenv
          :summary:

API
~~~

.. py:class:: AbsolutePathParamType
   :canonical: aiida.cmdline.params.types.path.AbsolutePathParamType

   Bases: :py:obj:`click.Path`

   .. autodoc2-docstring:: aiida.cmdline.params.types.path.AbsolutePathParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.path.AbsolutePathParamType.name
      :value: 'AbsolutePath'

      .. autodoc2-docstring:: aiida.cmdline.params.types.path.AbsolutePathParamType.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.path.AbsolutePathParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.path.AbsolutePathParamType.convert

   .. py:method:: __repr__()
      :canonical: aiida.cmdline.params.types.path.AbsolutePathParamType.__repr__

      .. autodoc2-docstring:: aiida.cmdline.params.types.path.AbsolutePathParamType.__repr__

.. py:class:: CalculationParamType
   :canonical: aiida.cmdline.params.types.calculation.CalculationParamType

   Bases: :py:obj:`aiida.cmdline.params.types.identifier.IdentifierParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.calculation.CalculationParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.calculation.CalculationParamType.name
      :value: 'Calculation'

      .. autodoc2-docstring:: aiida.cmdline.params.types.calculation.CalculationParamType.name

   .. py:property:: orm_class_loader
      :canonical: aiida.cmdline.params.types.calculation.CalculationParamType.orm_class_loader

      .. autodoc2-docstring:: aiida.cmdline.params.types.calculation.CalculationParamType.orm_class_loader

.. py:class:: CodeParamType(sub_classes=None, entry_point=None)
   :canonical: aiida.cmdline.params.types.code.CodeParamType

   Bases: :py:obj:`aiida.cmdline.params.types.identifier.IdentifierParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.code.CodeParamType

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.code.CodeParamType.__init__

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.code.CodeParamType.name
      :value: 'Code'

      .. autodoc2-docstring:: aiida.cmdline.params.types.code.CodeParamType.name

   .. py:property:: orm_class_loader
      :canonical: aiida.cmdline.params.types.code.CodeParamType.orm_class_loader

      .. autodoc2-docstring:: aiida.cmdline.params.types.code.CodeParamType.orm_class_loader

   .. py:method:: shell_complete(ctx, param, incomplete)
      :canonical: aiida.cmdline.params.types.code.CodeParamType.shell_complete

      .. autodoc2-docstring:: aiida.cmdline.params.types.code.CodeParamType.shell_complete

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.code.CodeParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.code.CodeParamType.convert

.. py:class:: ComputerParamType
   :canonical: aiida.cmdline.params.types.computer.ComputerParamType

   Bases: :py:obj:`aiida.cmdline.params.types.identifier.IdentifierParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ComputerParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.computer.ComputerParamType.name
      :value: 'Computer'

      .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ComputerParamType.name

   .. py:property:: orm_class_loader
      :canonical: aiida.cmdline.params.types.computer.ComputerParamType.orm_class_loader

      .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ComputerParamType.orm_class_loader

   .. py:method:: shell_complete(ctx, param, incomplete)
      :canonical: aiida.cmdline.params.types.computer.ComputerParamType.shell_complete

      .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ComputerParamType.shell_complete

.. py:class:: ConfigOptionParamType
   :canonical: aiida.cmdline.params.types.config.ConfigOptionParamType

   Bases: :py:obj:`click.types.StringParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.config.ConfigOptionParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.config.ConfigOptionParamType.name
      :value: 'config option'

      .. autodoc2-docstring:: aiida.cmdline.params.types.config.ConfigOptionParamType.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.config.ConfigOptionParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.config.ConfigOptionParamType.convert

   .. py:method:: shell_complete(ctx, param, incomplete)
      :canonical: aiida.cmdline.params.types.config.ConfigOptionParamType.shell_complete

      .. autodoc2-docstring:: aiida.cmdline.params.types.config.ConfigOptionParamType.shell_complete

.. py:class:: DataParamType(sub_classes=None)
   :canonical: aiida.cmdline.params.types.data.DataParamType

   Bases: :py:obj:`aiida.cmdline.params.types.identifier.IdentifierParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.data.DataParamType

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.data.DataParamType.__init__

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.data.DataParamType.name
      :value: 'Data'

      .. autodoc2-docstring:: aiida.cmdline.params.types.data.DataParamType.name

   .. py:property:: orm_class_loader
      :canonical: aiida.cmdline.params.types.data.DataParamType.orm_class_loader

      .. autodoc2-docstring:: aiida.cmdline.params.types.data.DataParamType.orm_class_loader

.. py:class:: DynamicEntryPointCommandGroup(command, entry_point_group: str, entry_point_name_filter='.*', **kwargs)
   :canonical: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup

   Bases: :py:obj:`aiida.cmdline.groups.verdi.VerdiCommandGroup`

   .. autodoc2-docstring:: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.__init__

   .. py:method:: list_commands(ctx) -> list[str]
      :canonical: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.list_commands

      .. autodoc2-docstring:: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.list_commands

   .. py:method:: get_command(ctx, cmd_name)
      :canonical: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.get_command

      .. autodoc2-docstring:: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.get_command

   .. py:method:: create_command(entry_point)
      :canonical: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.create_command

      .. autodoc2-docstring:: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.create_command

   .. py:method:: create_options(entry_point)
      :canonical: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.create_options

      .. autodoc2-docstring:: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.create_options

   .. py:method:: list_options(entry_point)
      :canonical: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.list_options

      .. autodoc2-docstring:: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.list_options

   .. py:method:: create_option(name, spec)
      :canonical: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.create_option
      :staticmethod:

      .. autodoc2-docstring:: aiida.cmdline.groups.dynamic.DynamicEntryPointCommandGroup.create_option

.. py:class:: EmailType
   :canonical: aiida.cmdline.params.types.strings.EmailType

   Bases: :py:obj:`click.types.StringParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EmailType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.strings.EmailType.name
      :value: 'email'

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EmailType.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.strings.EmailType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EmailType.convert

   .. py:method:: __repr__()
      :canonical: aiida.cmdline.params.types.strings.EmailType.__repr__

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EmailType.__repr__

.. py:class:: EntryPointType
   :canonical: aiida.cmdline.params.types.strings.EntryPointType

   Bases: :py:obj:`aiida.cmdline.params.types.strings.NonEmptyStringParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EntryPointType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.strings.EntryPointType.name
      :value: 'entrypoint'

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EntryPointType.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.strings.EntryPointType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EntryPointType.convert

   .. py:method:: __repr__()
      :canonical: aiida.cmdline.params.types.strings.EntryPointType.__repr__

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.EntryPointType.__repr__

.. py:class:: FileOrUrl(timeout_seconds=URL_TIMEOUT_SECONDS, **kwargs)
   :canonical: aiida.cmdline.params.types.path.FileOrUrl

   Bases: :py:obj:`click.File`

   .. autodoc2-docstring:: aiida.cmdline.params.types.path.FileOrUrl

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.path.FileOrUrl.__init__

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.path.FileOrUrl.name
      :value: 'FileOrUrl'

      .. autodoc2-docstring:: aiida.cmdline.params.types.path.FileOrUrl.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.path.FileOrUrl.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.path.FileOrUrl.convert

   .. py:method:: get_url(url, param, ctx)
      :canonical: aiida.cmdline.params.types.path.FileOrUrl.get_url

      .. autodoc2-docstring:: aiida.cmdline.params.types.path.FileOrUrl.get_url

.. py:class:: GroupParamType(create_if_not_exist=False, sub_classes=('aiida.groups:core', ))
   :canonical: aiida.cmdline.params.types.group.GroupParamType

   Bases: :py:obj:`aiida.cmdline.params.types.identifier.IdentifierParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.group.GroupParamType

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.group.GroupParamType.__init__

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.group.GroupParamType.name
      :value: 'Group'

      .. autodoc2-docstring:: aiida.cmdline.params.types.group.GroupParamType.name

   .. py:property:: orm_class_loader
      :canonical: aiida.cmdline.params.types.group.GroupParamType.orm_class_loader

      .. autodoc2-docstring:: aiida.cmdline.params.types.group.GroupParamType.orm_class_loader

   .. py:method:: shell_complete(ctx, param, incomplete)
      :canonical: aiida.cmdline.params.types.group.GroupParamType.shell_complete

      .. autodoc2-docstring:: aiida.cmdline.params.types.group.GroupParamType.shell_complete

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.group.GroupParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.group.GroupParamType.convert

.. py:class:: HostnameType
   :canonical: aiida.cmdline.params.types.strings.HostnameType

   Bases: :py:obj:`click.types.StringParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.strings.HostnameType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.strings.HostnameType.name
      :value: 'hostname'

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.HostnameType.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.strings.HostnameType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.HostnameType.convert

   .. py:method:: __repr__()
      :canonical: aiida.cmdline.params.types.strings.HostnameType.__repr__

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.HostnameType.__repr__

.. py:class:: IdentifierParamType(sub_classes=None)
   :canonical: aiida.cmdline.params.types.identifier.IdentifierParamType

   Bases: :py:obj:`click.ParamType`, :py:obj:`abc.ABC`

   .. autodoc2-docstring:: aiida.cmdline.params.types.identifier.IdentifierParamType

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.identifier.IdentifierParamType.__init__

   .. py:property:: orm_class_loader
      :canonical: aiida.cmdline.params.types.identifier.IdentifierParamType.orm_class_loader
      :abstractmethod:

      .. autodoc2-docstring:: aiida.cmdline.params.types.identifier.IdentifierParamType.orm_class_loader

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.identifier.IdentifierParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.identifier.IdentifierParamType.convert

.. py:class:: LabelStringType
   :canonical: aiida.cmdline.params.types.strings.LabelStringType

   Bases: :py:obj:`aiida.cmdline.params.types.strings.NonEmptyStringParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.strings.LabelStringType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.strings.LabelStringType.name
      :value: 'labelstring'

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.LabelStringType.name

   .. py:attribute:: ALPHABET
      :canonical: aiida.cmdline.params.types.strings.LabelStringType.ALPHABET
      :value: '\\w\\.\\-'

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.LabelStringType.ALPHABET

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.strings.LabelStringType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.LabelStringType.convert

   .. py:method:: __repr__()
      :canonical: aiida.cmdline.params.types.strings.LabelStringType.__repr__

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.LabelStringType.__repr__

.. py:class:: LazyChoice(get_choices)
   :canonical: aiida.cmdline.params.types.choice.LazyChoice

   Bases: :py:obj:`click.ParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice.__init__

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.choice.LazyChoice.name
      :value: 'choice'

      .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice.name

   .. py:property:: _click_choice
      :canonical: aiida.cmdline.params.types.choice.LazyChoice._click_choice

      .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice._click_choice

   .. py:property:: choices
      :canonical: aiida.cmdline.params.types.choice.LazyChoice.choices

      .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice.choices

   .. py:method:: get_metavar(param)
      :canonical: aiida.cmdline.params.types.choice.LazyChoice.get_metavar

      .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice.get_metavar

   .. py:method:: get_missing_message(param)
      :canonical: aiida.cmdline.params.types.choice.LazyChoice.get_missing_message

      .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice.get_missing_message

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.choice.LazyChoice.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice.convert

   .. py:method:: __repr__()
      :canonical: aiida.cmdline.params.types.choice.LazyChoice.__repr__

      .. autodoc2-docstring:: aiida.cmdline.params.types.choice.LazyChoice.__repr__

.. py:class:: MpirunCommandParamType
   :canonical: aiida.cmdline.params.types.computer.MpirunCommandParamType

   Bases: :py:obj:`click.types.StringParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.computer.MpirunCommandParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.computer.MpirunCommandParamType.name
      :value: 'mpiruncommandstring'

      .. autodoc2-docstring:: aiida.cmdline.params.types.computer.MpirunCommandParamType.name

   .. py:method:: __repr__()
      :canonical: aiida.cmdline.params.types.computer.MpirunCommandParamType.__repr__

      .. autodoc2-docstring:: aiida.cmdline.params.types.computer.MpirunCommandParamType.__repr__

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.computer.MpirunCommandParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.computer.MpirunCommandParamType.convert

.. py:class:: MultipleValueParamType(param_type)
   :canonical: aiida.cmdline.params.types.multiple.MultipleValueParamType

   Bases: :py:obj:`click.ParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.multiple.MultipleValueParamType

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.multiple.MultipleValueParamType.__init__

   .. py:method:: get_metavar(param)
      :canonical: aiida.cmdline.params.types.multiple.MultipleValueParamType.get_metavar

      .. autodoc2-docstring:: aiida.cmdline.params.types.multiple.MultipleValueParamType.get_metavar

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.multiple.MultipleValueParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.multiple.MultipleValueParamType.convert

.. py:class:: NodeParamType
   :canonical: aiida.cmdline.params.types.node.NodeParamType

   Bases: :py:obj:`aiida.cmdline.params.types.identifier.IdentifierParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.node.NodeParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.node.NodeParamType.name
      :value: 'Node'

      .. autodoc2-docstring:: aiida.cmdline.params.types.node.NodeParamType.name

   .. py:property:: orm_class_loader
      :canonical: aiida.cmdline.params.types.node.NodeParamType.orm_class_loader

      .. autodoc2-docstring:: aiida.cmdline.params.types.node.NodeParamType.orm_class_loader

.. py:class:: NonEmptyStringParamType
   :canonical: aiida.cmdline.params.types.strings.NonEmptyStringParamType

   Bases: :py:obj:`click.types.StringParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.strings.NonEmptyStringParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.strings.NonEmptyStringParamType.name
      :value: 'nonemptystring'

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.NonEmptyStringParamType.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.strings.NonEmptyStringParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.NonEmptyStringParamType.convert

   .. py:method:: __repr__()
      :canonical: aiida.cmdline.params.types.strings.NonEmptyStringParamType.__repr__

      .. autodoc2-docstring:: aiida.cmdline.params.types.strings.NonEmptyStringParamType.__repr__

.. py:class:: PathOrUrl(timeout_seconds=URL_TIMEOUT_SECONDS, **kwargs)
   :canonical: aiida.cmdline.params.types.path.PathOrUrl

   Bases: :py:obj:`click.Path`

   .. autodoc2-docstring:: aiida.cmdline.params.types.path.PathOrUrl

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.path.PathOrUrl.__init__

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.path.PathOrUrl.name
      :value: 'PathOrUrl'

      .. autodoc2-docstring:: aiida.cmdline.params.types.path.PathOrUrl.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.path.PathOrUrl.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.path.PathOrUrl.convert

   .. py:method:: checks_url(url, param, ctx)
      :canonical: aiida.cmdline.params.types.path.PathOrUrl.checks_url

      .. autodoc2-docstring:: aiida.cmdline.params.types.path.PathOrUrl.checks_url

.. py:class:: PluginParamType(group=None, load=False, *args, **kwargs)
   :canonical: aiida.cmdline.params.types.plugin.PluginParamType

   Bases: :py:obj:`aiida.cmdline.params.types.strings.EntryPointType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.__init__

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.name
      :value: 'plugin'

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.name

   .. py:attribute:: _factory_mapping
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType._factory_mapping
      :value: None

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType._factory_mapping

   .. py:method:: _init_entry_points()
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType._init_entry_points

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType._init_entry_points

   .. py:property:: groups
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.groups

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.groups

   .. py:property:: has_potential_ambiguity
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.has_potential_ambiguity

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.has_potential_ambiguity

   .. py:method:: get_valid_arguments()
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.get_valid_arguments

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.get_valid_arguments

   .. py:method:: get_possibilities(incomplete='')
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.get_possibilities

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.get_possibilities

   .. py:method:: shell_complete(ctx, param, incomplete)
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.shell_complete

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.shell_complete

   .. py:method:: get_missing_message(param)
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.get_missing_message

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.get_missing_message

   .. py:method:: get_entry_point_from_string(entry_point_string)
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.get_entry_point_from_string

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.get_entry_point_from_string

   .. py:method:: validate_entry_point_group(group)
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.validate_entry_point_group

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.validate_entry_point_group

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.plugin.PluginParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.plugin.PluginParamType.convert

.. py:class:: ProcessParamType
   :canonical: aiida.cmdline.params.types.process.ProcessParamType

   Bases: :py:obj:`aiida.cmdline.params.types.identifier.IdentifierParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.process.ProcessParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.process.ProcessParamType.name
      :value: 'Process'

      .. autodoc2-docstring:: aiida.cmdline.params.types.process.ProcessParamType.name

   .. py:property:: orm_class_loader
      :canonical: aiida.cmdline.params.types.process.ProcessParamType.orm_class_loader

      .. autodoc2-docstring:: aiida.cmdline.params.types.process.ProcessParamType.orm_class_loader

.. py:class:: ProfileParamType(*args, **kwargs)
   :canonical: aiida.cmdline.params.types.profile.ProfileParamType

   Bases: :py:obj:`aiida.cmdline.params.types.strings.LabelStringType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.profile.ProfileParamType

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.profile.ProfileParamType.__init__

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.profile.ProfileParamType.name
      :value: 'profile'

      .. autodoc2-docstring:: aiida.cmdline.params.types.profile.ProfileParamType.name

   .. py:method:: deconvert_default(value)
      :canonical: aiida.cmdline.params.types.profile.ProfileParamType.deconvert_default
      :staticmethod:

      .. autodoc2-docstring:: aiida.cmdline.params.types.profile.ProfileParamType.deconvert_default

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.profile.ProfileParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.profile.ProfileParamType.convert

   .. py:method:: shell_complete(ctx, param, incomplete)
      :canonical: aiida.cmdline.params.types.profile.ProfileParamType.shell_complete

      .. autodoc2-docstring:: aiida.cmdline.params.types.profile.ProfileParamType.shell_complete

.. py:class:: ShebangParamType
   :canonical: aiida.cmdline.params.types.computer.ShebangParamType

   Bases: :py:obj:`click.types.StringParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ShebangParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.computer.ShebangParamType.name
      :value: 'shebangline'

      .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ShebangParamType.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.computer.ShebangParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ShebangParamType.convert

   .. py:method:: __repr__()
      :canonical: aiida.cmdline.params.types.computer.ShebangParamType.__repr__

      .. autodoc2-docstring:: aiida.cmdline.params.types.computer.ShebangParamType.__repr__

.. py:class:: UserParamType(create=False)
   :canonical: aiida.cmdline.params.types.user.UserParamType

   Bases: :py:obj:`click.ParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.user.UserParamType

   .. rubric:: Initialization

   .. autodoc2-docstring:: aiida.cmdline.params.types.user.UserParamType.__init__

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.user.UserParamType.name
      :value: 'user'

      .. autodoc2-docstring:: aiida.cmdline.params.types.user.UserParamType.name

   .. py:method:: convert(value, param, ctx)
      :canonical: aiida.cmdline.params.types.user.UserParamType.convert

      .. autodoc2-docstring:: aiida.cmdline.params.types.user.UserParamType.convert

   .. py:method:: shell_complete(ctx, param, incomplete)
      :canonical: aiida.cmdline.params.types.user.UserParamType.shell_complete

      .. autodoc2-docstring:: aiida.cmdline.params.types.user.UserParamType.shell_complete

.. py:class:: VerdiCommandGroup
   :canonical: aiida.cmdline.groups.verdi.VerdiCommandGroup

   Bases: :py:obj:`click.Group`

   .. autodoc2-docstring:: aiida.cmdline.groups.verdi.VerdiCommandGroup

   .. py:attribute:: context_class
      :canonical: aiida.cmdline.groups.verdi.VerdiCommandGroup.context_class
      :value: None

      .. autodoc2-docstring:: aiida.cmdline.groups.verdi.VerdiCommandGroup.context_class

   .. py:method:: add_verbosity_option(cmd)
      :canonical: aiida.cmdline.groups.verdi.VerdiCommandGroup.add_verbosity_option
      :staticmethod:

      .. autodoc2-docstring:: aiida.cmdline.groups.verdi.VerdiCommandGroup.add_verbosity_option

   .. py:method:: fail_with_suggestions(ctx, cmd_name)
      :canonical: aiida.cmdline.groups.verdi.VerdiCommandGroup.fail_with_suggestions

      .. autodoc2-docstring:: aiida.cmdline.groups.verdi.VerdiCommandGroup.fail_with_suggestions

   .. py:method:: get_command(ctx, cmd_name)
      :canonical: aiida.cmdline.groups.verdi.VerdiCommandGroup.get_command

      .. autodoc2-docstring:: aiida.cmdline.groups.verdi.VerdiCommandGroup.get_command

   .. py:method:: group(*args, **kwargs)
      :canonical: aiida.cmdline.groups.verdi.VerdiCommandGroup.group

      .. autodoc2-docstring:: aiida.cmdline.groups.verdi.VerdiCommandGroup.group

.. py:class:: WorkflowParamType
   :canonical: aiida.cmdline.params.types.workflow.WorkflowParamType

   Bases: :py:obj:`aiida.cmdline.params.types.identifier.IdentifierParamType`

   .. autodoc2-docstring:: aiida.cmdline.params.types.workflow.WorkflowParamType

   .. py:attribute:: name
      :canonical: aiida.cmdline.params.types.workflow.WorkflowParamType.name
      :value: 'WorkflowNode'

      .. autodoc2-docstring:: aiida.cmdline.params.types.workflow.WorkflowParamType.name

   .. py:property:: orm_class_loader
      :canonical: aiida.cmdline.params.types.workflow.WorkflowParamType.orm_class_loader

      .. autodoc2-docstring:: aiida.cmdline.params.types.workflow.WorkflowParamType.orm_class_loader

.. py:function:: dbenv()
   :canonical: aiida.cmdline.utils.decorators.dbenv

   .. autodoc2-docstring:: aiida.cmdline.utils.decorators.dbenv

.. py:function:: echo_critical(message: str, bold: bool = False, nl: bool = True, err: bool = True, prefix: bool = True) -> None
   :canonical: aiida.cmdline.utils.echo.echo_critical

   .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_critical

.. py:function:: echo_dictionary(dictionary, fmt='json+date', sort_keys=True)
   :canonical: aiida.cmdline.utils.echo.echo_dictionary

   .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_dictionary

.. py:function:: echo_error(message: str, bold: bool = False, nl: bool = True, err: bool = True, prefix: bool = True) -> None
   :canonical: aiida.cmdline.utils.echo.echo_error

   .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_error

.. py:function:: echo_info(message: str, bold: bool = False, nl: bool = True, err: bool = False, prefix: bool = True) -> None
   :canonical: aiida.cmdline.utils.echo.echo_info

   .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_info

.. py:function:: echo_report(message: str, bold: bool = False, nl: bool = True, err: bool = False, prefix: bool = True) -> None
   :canonical: aiida.cmdline.utils.echo.echo_report

   .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_report

.. py:function:: echo_success(message: str, bold: bool = False, nl: bool = True, err: bool = False, prefix: bool = True) -> None
   :canonical: aiida.cmdline.utils.echo.echo_success

   .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_success

.. py:function:: echo_warning(message: str, bold: bool = False, nl: bool = True, err: bool = False, prefix: bool = True) -> None
   :canonical: aiida.cmdline.utils.echo.echo_warning

   .. autodoc2-docstring:: aiida.cmdline.utils.echo.echo_warning

.. py:function:: format_call_graph(calc_node, max_depth: int = None, info_fn=calc_info)
   :canonical: aiida.cmdline.utils.ascii_vis.format_call_graph

   .. autodoc2-docstring:: aiida.cmdline.utils.ascii_vis.format_call_graph

.. py:function:: is_verbose()
   :canonical: aiida.cmdline.utils.common.is_verbose

   .. autodoc2-docstring:: aiida.cmdline.utils.common.is_verbose

.. py:function:: only_if_daemon_running(echo_function=echo.echo_critical, message=None)
   :canonical: aiida.cmdline.utils.decorators.only_if_daemon_running

   .. autodoc2-docstring:: aiida.cmdline.utils.decorators.only_if_daemon_running

.. py:function:: with_dbenv()
   :canonical: aiida.cmdline.utils.decorators.with_dbenv

   .. autodoc2-docstring:: aiida.cmdline.utils.decorators.with_dbenv
